from __future__ import annotations

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from typing import Final

FIGURE_CAPTION: Final[str] = './/figure/figcaption/p'
